/**
 * AutoDAO - Generic DAO on steroids implementation for Java.
 * Copyright (C) 2008-2009  Marat Radchenko <slonopotamus@users.sourceforge.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.autodao.hibernate;

import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.w3c.dom.Element;

/** Helper functions for custom Spring namespace tag parsing. */
final class ParserUtils {
  private static final String SESSION_FACTORY_ATTRIBUTE = "session-factory";
  private static final String TRANSACTION_MANAGER_ATTRIBUTE = "transaction-manager";

  private ParserUtils() {
  }

  static void applyDaoParams(final BeanDefinitionBuilder builder,
                             final Element element,
                             final String daoInterfaceName,
                             final String entityName) {
    final String sessionFactory;
    if (element.hasAttribute(SESSION_FACTORY_ATTRIBUTE)) {
      sessionFactory = element.getAttribute(SESSION_FACTORY_ATTRIBUTE);
    } else {
      sessionFactory = "sessionFactory";
    }
    final String transactionManager;
    if (element.hasAttribute(TRANSACTION_MANAGER_ATTRIBUTE)) {
      transactionManager = element.getAttribute(TRANSACTION_MANAGER_ATTRIBUTE);
    } else {
      transactionManager = "transactionManager";
    }
    builder
        .addConstructorArgValue(daoInterfaceName)
        .addConstructorArgReference(sessionFactory)
        .addConstructorArgReference(transactionManager)
        .addConstructorArgValue(entityName);
  }
}
